@@ -28,13 +28,17 @@
 #include "logindialog.h"
 #include "SettingsDialog.h"
 #include "TrackView.h"
+#include "AlbumView.h"
 #include "QueueView.h"
 #include "SpectrumAnalyzer.h"
 #include "customlabel.h"
+#include "OssoWrapper.h"
 
 
 //defines
 
+#define APP_VERSION "0.1.0-1" //application version string
+
 #define PLAYLIST_LOADING_TIMEOUT  30 //timeout before giving up on waiting for playlists to load (in seconds)
 
 class MainWindow : public QMainWindow
@@ -64,9 +68,13 @@ private:
 
     TrackView* m_pTrackView;
 
-    QueueView* m_pQueueView;
+    AlbumView* m_pAlbumView;
 
-    Spotify::Session* m_pSession;
+    QueueView* m_pQueueView; //playqueue (Now Playing) view instance
+
+    Spotify::Session* m_pSession; //main Spotify session instance (handles communication with Spotify backend)
+
+    OssoWrapper* m_pOssoWrapper; //wrapper instance for libosso
 
     QPushButton m_SearchBtn;
 
@@ -96,24 +104,23 @@ private:
 
     QList<Spotify::Track*> m_PlayQueue; //current playqueue
 
-    qint32 m_currQueuePos; //current playqueue position
-
-    qint32 m_currShufflePos; //current position in shuffle queue (when shuffle mode is active)
+    qint32 m_currQueuePos; //current position in the play queue (position of track being played)
 
     bool m_playing; //TRUE if in playing mode
 
     qint64 m_currPlaybackPos; //playback position for currently playing track
 
-    qint64 m_currBuffPos; //buffering position for currently playing track
-
-    void logout(); //logout current user and display the login dialog
-
     QMessageBox m_AboutDlg; //App About dialog instance
 
     QTimer *m_pTimeoutTimer; //timer used for detecting timeouts (i.e., during playlist loading)
 
     bool m_AudioInit; //TRUE in case audio playback thread initialised
 
+    void logout(); //logout current user and display the login dialog
+
+    void initAboutDialog(); //setup the application about dialog
+
+
 
 private slots:
 
@@ -124,17 +131,17 @@ private slots:
      void OnLoginDialogRejected();
      void OnMainMenuAction(QAction* action);
      void OnPlayingState(bool state);
-     void OnSetPlayQueue(QList<Spotify::Track*> queue);
-     void OnPlayQueuePosUpdated(qint32 pos, qint32 shufflePos);
+     void OnSetPlayQueue(const QList<Spotify::Track*>& queue);
+     void OnPlayQueuePosUpdated(qint32 pos);
      void OnNowPlaying();
      void OnSearch();
      void OnSearchComplete(Spotify::Search* search);
-     void OnTrackPosUpdated(qint64 pos);
      void OnPlaybackPositionUpdated(qint64 pos);
      void OnPlaybackTokenLost();
-     void OnActiveQueueViewChanged(bool active, bool shuffleActive);
      void OnSettingsSaved();
      void OnPlaylistLoadingTimeout();
+     void OnDisplayFMTransmitterDialog();
+     void OnShowAlbumView(Spotify::Album* album);
 
 signals:
 
